aboutsummaryrefslogtreecommitdiff
path: root/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/CreateSignatureEnvironmentProfile.java
diff options
context:
space:
mode:
Diffstat (limited to 'moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/CreateSignatureEnvironmentProfile.java')
-rw-r--r--moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/CreateSignatureEnvironmentProfile.java48
1 files changed, 24 insertions, 24 deletions
diff --git a/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/CreateSignatureEnvironmentProfile.java b/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/CreateSignatureEnvironmentProfile.java
index 7d88143..e0c9111 100644
--- a/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/CreateSignatureEnvironmentProfile.java
+++ b/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/CreateSignatureEnvironmentProfile.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.15 at 04:11:53 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:50 PM CET
//
@@ -10,29 +10,29 @@ package at.gv.egiz.moasig;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlElement;
-import javax.xml.bind.annotation.XmlRootElement;
-import javax.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlElement;
+import jakarta.xml.bind.annotation.XmlRootElement;
+import jakarta.xml.bind.annotation.XmlType;
/**
- * <p>Java class for anonymous complex type.
+ * <p>Java-Klasse für anonymous complex type.
*
- * <p>The following schema fragment specifies the expected content contained within this class.
+ * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
* <pre>
- * &lt;complexType>
- * &lt;complexContent>
- * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
- * &lt;sequence>
- * &lt;element name="CreateSignatureLocation" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}CreateSignatureLocationType"/>
- * &lt;element name="Supplement" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}XMLDataObjectAssociationType" maxOccurs="unbounded" minOccurs="0"/>
- * &lt;/sequence>
- * &lt;/restriction>
- * &lt;/complexContent>
- * &lt;/complexType>
+ * &lt;complexType&gt;
+ * &lt;complexContent&gt;
+ * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
+ * &lt;sequence&gt;
+ * &lt;element name="CreateSignatureLocation" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}CreateSignatureLocationType"/&gt;
+ * &lt;element name="Supplement" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}XMLDataObjectAssociationType" maxOccurs="unbounded" minOccurs="0"/&gt;
+ * &lt;/sequence&gt;
+ * &lt;/restriction&gt;
+ * &lt;/complexContent&gt;
+ * &lt;/complexType&gt;
* </pre>
*
*
@@ -51,7 +51,7 @@ public class CreateSignatureEnvironmentProfile {
protected List<XMLDataObjectAssociationType> supplement;
/**
- * Gets the value of the createSignatureLocation property.
+ * Ruft den Wert der createSignatureLocation-Eigenschaft ab.
*
* @return
* possible object is
@@ -63,7 +63,7 @@ public class CreateSignatureEnvironmentProfile {
}
/**
- * Sets the value of the createSignatureLocation property.
+ * Legt den Wert der createSignatureLocation-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -80,7 +80,7 @@ public class CreateSignatureEnvironmentProfile {
* <p>
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a <CODE>set</CODE> method for the supplement property.
*
* <p>
@@ -80,7 +80,7 @@ public class CreateSignatureEnvironmentProfile {
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
+ * returned list will be present inside the Jakarta XML Binding object.
* This is why there is not a <CODE>set</CODE> method for the supplement property.
*